@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DMARC;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20190501'; # VERSION
+our $VERSION = '2.20190502'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -446,7 +446,7 @@ sub _process_dmarc_for {
             $dmarc_disposition = 'none';
         }
         elsif ( $config->{'no_list_reject'} && $self->{'is_list'} ) {
-            if ( $config->{'arc_before_list'} && $have_arc ) {
+            if ( $config->{'arc_before_list'} && $have_arc && $self->get_handler('ARC')->get_trusted_arc_authentication_results ) {
                 $self->dbgout( 'DMARCReject', "Policy reject not overridden for list mail with trusted ARC chain", LOG_INFO );
             }
             else {
@@ -907,7 +907,7 @@ Mail::Milter::Authentication::Handler::DMARC
 
 =head1 VERSION
 
-version 2.20190501
+version 2.20190502
 
 =head1 DESCRIPTION
 
